@@ -192,27 +192,27 @@ from typeguard import check_type
 
 from ._jsii import *
 
-import aws_cdk
-import aws_cdk.aws_iam
-import aws_cdk.aws_lambda
-import constructs
+import aws_cdk as _aws_cdk_ceddda9d
+import aws_cdk.aws_iam as _aws_cdk_aws_iam_ceddda9d
+import aws_cdk.aws_lambda as _aws_cdk_aws_lambda_ceddda9d
+import constructs as _constructs_77d1e7e8
 
 
 class BashExecFunction(
-    constructs.Construct,
+    _constructs_77d1e7e8.Construct,
     metaclass=jsii.JSIIMeta,
     jsii_type="cdk-lambda-bash.BashExecFunction",
 ):
     def __init__(
         self,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
         id: builtins.str,
         *,
         script: builtins.str,
         dockerfile: typing.Optional[builtins.str] = None,
         environment: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
-        role: typing.Optional[aws_cdk.aws_iam.IRole] = None,
-        timeout: typing.Optional[aws_cdk.Duration] = None,
+        role: typing.Optional[_aws_cdk_aws_iam_ceddda9d.IRole] = None,
+        timeout: typing.Optional[_aws_cdk_ceddda9d.Duration] = None,
     ) -> None:
         '''
         :param scope: -
@@ -224,18 +224,7 @@ class BashExecFunction(
         :param timeout: The function execution time (in seconds) after which Lambda terminates the function. Because the execution time affects cost, set this value based on the function's expected execution time. Default: - Duration.seconds(60)
         '''
         if __debug__:
-            def stub(
-                scope: constructs.Construct,
-                id: builtins.str,
-                *,
-                script: builtins.str,
-                dockerfile: typing.Optional[builtins.str] = None,
-                environment: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
-                role: typing.Optional[aws_cdk.aws_iam.IRole] = None,
-                timeout: typing.Optional[aws_cdk.Duration] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__634a45e063379d008b93c0445c3baf34458772aa792f9d20f521088626f550c2)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = BashExecFunctionProps(
@@ -253,18 +242,18 @@ class BashExecFunction(
         self,
         *,
         run_on_update: typing.Optional[builtins.bool] = None,
-    ) -> aws_cdk.CustomResource:
+    ) -> _aws_cdk_ceddda9d.CustomResource:
         '''
         :param run_on_update: whether to run the lambda function again on the provider update. Default: false;
         '''
         ops = RunOps(run_on_update=run_on_update)
 
-        return typing.cast(aws_cdk.CustomResource, jsii.invoke(self, "run", [ops]))
+        return typing.cast(_aws_cdk_ceddda9d.CustomResource, jsii.invoke(self, "run", [ops]))
 
     @builtins.property
     @jsii.member(jsii_name="handler")
-    def handler(self) -> aws_cdk.aws_lambda.DockerImageFunction:
-        return typing.cast(aws_cdk.aws_lambda.DockerImageFunction, jsii.get(self, "handler"))
+    def handler(self) -> _aws_cdk_aws_lambda_ceddda9d.DockerImageFunction:
+        return typing.cast(_aws_cdk_aws_lambda_ceddda9d.DockerImageFunction, jsii.get(self, "handler"))
 
 
 @jsii.data_type(
@@ -285,8 +274,8 @@ class BashExecFunctionProps:
         script: builtins.str,
         dockerfile: typing.Optional[builtins.str] = None,
         environment: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
-        role: typing.Optional[aws_cdk.aws_iam.IRole] = None,
-        timeout: typing.Optional[aws_cdk.Duration] = None,
+        role: typing.Optional[_aws_cdk_aws_iam_ceddda9d.IRole] = None,
+        timeout: typing.Optional[_aws_cdk_ceddda9d.Duration] = None,
     ) -> None:
         '''
         :param script: The path of the shell script to be executed.
@@ -296,22 +285,13 @@ class BashExecFunctionProps:
         :param timeout: The function execution time (in seconds) after which Lambda terminates the function. Because the execution time affects cost, set this value based on the function's expected execution time. Default: - Duration.seconds(60)
         '''
         if __debug__:
-            def stub(
-                *,
-                script: builtins.str,
-                dockerfile: typing.Optional[builtins.str] = None,
-                environment: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
-                role: typing.Optional[aws_cdk.aws_iam.IRole] = None,
-                timeout: typing.Optional[aws_cdk.Duration] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__38ce028794aa7d3deb9edd0d37d99548e962a5625501b9c9827320b5fb87a06f)
             check_type(argname="argument script", value=script, expected_type=type_hints["script"])
             check_type(argname="argument dockerfile", value=dockerfile, expected_type=type_hints["dockerfile"])
             check_type(argname="argument environment", value=environment, expected_type=type_hints["environment"])
             check_type(argname="argument role", value=role, expected_type=type_hints["role"])
             check_type(argname="argument timeout", value=timeout, expected_type=type_hints["timeout"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "script": script,
         }
         if dockerfile is not None:
@@ -345,16 +325,16 @@ class BashExecFunctionProps:
         return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], result)
 
     @builtins.property
-    def role(self) -> typing.Optional[aws_cdk.aws_iam.IRole]:
+    def role(self) -> typing.Optional[_aws_cdk_aws_iam_ceddda9d.IRole]:
         '''Custom lambda execution role.
 
         :default: - auto generated role.
         '''
         result = self._values.get("role")
-        return typing.cast(typing.Optional[aws_cdk.aws_iam.IRole], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_iam_ceddda9d.IRole], result)
 
     @builtins.property
-    def timeout(self) -> typing.Optional[aws_cdk.Duration]:
+    def timeout(self) -> typing.Optional[_aws_cdk_ceddda9d.Duration]:
         '''The function execution time (in seconds) after which Lambda terminates the function.
 
         Because the execution time affects cost, set this value based on the function's expected execution time.
@@ -362,7 +342,7 @@ class BashExecFunctionProps:
         :default: - Duration.seconds(60)
         '''
         result = self._values.get("timeout")
-        return typing.cast(typing.Optional[aws_cdk.Duration], result)
+        return typing.cast(typing.Optional[_aws_cdk_ceddda9d.Duration], result)
 
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -387,11 +367,9 @@ class RunOps:
         :param run_on_update: whether to run the lambda function again on the provider update. Default: false;
         '''
         if __debug__:
-            def stub(*, run_on_update: typing.Optional[builtins.bool] = None) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__c5eb9ecdcaa8af8fbb8635d7db938fe17a1fcb455a8b83b8ac1865ea151b61f9)
             check_type(argname="argument run_on_update", value=run_on_update, expected_type=type_hints["run_on_update"])
-        self._values: typing.Dict[str, typing.Any] = {}
+        self._values: typing.Dict[builtins.str, typing.Any] = {}
         if run_on_update is not None:
             self._values["run_on_update"] = run_on_update
 
@@ -423,3 +401,34 @@ __all__ = [
 ]
 
 publication.publish()
+
+def _typecheckingstub__634a45e063379d008b93c0445c3baf34458772aa792f9d20f521088626f550c2(
+    scope: _constructs_77d1e7e8.Construct,
+    id: builtins.str,
+    *,
+    script: builtins.str,
+    dockerfile: typing.Optional[builtins.str] = None,
+    environment: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
+    role: typing.Optional[_aws_cdk_aws_iam_ceddda9d.IRole] = None,
+    timeout: typing.Optional[_aws_cdk_ceddda9d.Duration] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__38ce028794aa7d3deb9edd0d37d99548e962a5625501b9c9827320b5fb87a06f(
+    *,
+    script: builtins.str,
+    dockerfile: typing.Optional[builtins.str] = None,
+    environment: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
+    role: typing.Optional[_aws_cdk_aws_iam_ceddda9d.IRole] = None,
+    timeout: typing.Optional[_aws_cdk_ceddda9d.Duration] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__c5eb9ecdcaa8af8fbb8635d7db938fe17a1fcb455a8b83b8ac1865ea151b61f9(
+    *,
+    run_on_update: typing.Optional[builtins.bool] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
